@@ -1,4 +1,4 @@
-# Copyright (C) 2017  Brodie Gaslam
+# Copyright (C) 2018  Brodie Gaslam
 #
 # This file is part of "diffobj - Diffs for R Objects"
 #
@@ -20,6 +20,8 @@ is.less_flags <-
 # for checking the limits, if successful returns an integer(2L) vector,
 # otherwise a character vector to sprintf as an error
 
+#' @include pager.R
+
 check_limit <- function(limit) {
   if(
     !is.numeric(limit) || any(is.na(limit)) ||
@@ -72,7 +74,6 @@ is.valid.palette.param <- function(x, param, palette) {
     )
   else if(
     (length(x) > 1L && is.null(names(x))) ||
-    (!is.null(names(x)) && !"" %in% names(x)) ||
     !all(names(x) %in% c("", valid.formats))
   )
     paste0(
@@ -80,6 +81,11 @@ is.valid.palette.param <- function(x, param, palette) {
       "names must include at least an empty name `\"\"` as well as names only ",
       "from `", dep(valid.formats), "`."
     )
+  else if ((!is.null(names(x)) && !"" %in% names(x)))
+    paste0(
+      "Argument `", param, "` must include at least one empty name `\"\"` if ",
+      "it has names."
+    )
   else TRUE
 }
 is.one.arg.fun <- function(x) {
@@ -193,11 +199,14 @@ check_args <- function(
       }
       cont <- try(auto_context(min.cont, max.cont))
       if(inherits(cont, "try-error"))
+        # nocov start
+        # should not be possible to get here given prior checks
         err(
           "Unable to instantiate an `AutoContext` object from provided ",
           "`context` argument.  Value should be integer(1L) and not NA, or ",
           "an `AutoContext` object as generated by `auto_context()`."
         )
+        # nocov end
       cont
     }
   }
@@ -221,7 +230,7 @@ check_args <- function(
     !is.integer(tab.stops) || !length(tab.stops) >= 1L || anyNA(tab.stops) ||
     !all(tab.stops > 0L)
   )
-    stop(
+    err(
       "Argument `tab.stops` must be integer containing at least one value and ",
       "with all values strictly positive"
     )
@@ -376,10 +385,12 @@ check_args <- function(
       err("Argument `format` must be one of `", dep(valid.formats) , "`.")
     if(format == "auto") {
       if(!is.int.1L(term.colors))
+        # nocov start
         err(
           "Logic Error: unexpected return from `crayon::num_colors()`; ",
           "contact maintainer."
         )
+        # nocov end
       # No recognized color alternatives, try to use HTML if we can
 
       format <- if(!term.colors %in% c(8, 256) || !pager.could.be.ansi) {
@@ -390,7 +401,7 @@ check_args <- function(
         "ansi8"
       } else if (term.colors == 256) {
         "ansi256"
-      } else stop("Logic error: unhandled format; contact maintainer.")
+      } else stop("Logic error: unhandled format; contact maintainer.") # nocov
     }
     style <- palette.of.styles[[
       format, get_pal_par(format, brightness), get_pal_par(format, color.mode)
@@ -416,14 +427,14 @@ check_args <- function(
           "`Style` object:"
     ) ) }
   } else if(!is(style, "Style"))
-    stop("Logic Error: unexpected style state; contact maintainer.")
+    stop("Logic Error: unexpected style state; contact maintainer.") # nocov
 
   # Attach specific pager if it was requested generated; if "auto" just let the
   # existing pager on the style be, which is done by not modifying @pager
 
   if(is(pager, "Pager")) style@pager <- pager
   else if(!identical(pager, "on"))
-    stop("Logic Error: Unexpected pager state; contact maintainer.")
+    stop("Logic Error: Unexpected pager state; contact maintainer.") # nocov
 
   # Check display width
 
